summaryrefslogtreecommitdiffstats
path: root/konqueror
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:53:50 -0600
committerSlávek Banko <slavek.banko@axis.cz>2012-06-03 03:26:29 +0200
commita5b44fbe44e58478ad74d819c5f4c36926d31872 (patch)
treefa07b25a5c2a60b5e0b438a0af16d06c9a5ac498 /konqueror
parent6a1f2b1b6b19b0dd47b1e58afff29a12ae158226 (diff)
downloadtdebase-a5b44fbe44e58478ad74d819c5f4c36926d31872.tar.gz
tdebase-a5b44fbe44e58478ad74d819c5f4c36926d31872.zip
Remove additional unneeded tq method conversions
(cherry picked from commit f64397c82fa94371ab4a64af28c4d0029f4cd93f)
Diffstat (limited to 'konqueror')
-rw-r--r--konqueror/about/konq_aboutpage.cc330
-rw-r--r--konqueror/client/kfmclient.cc4
-rw-r--r--konqueror/iconview/konq_iconview.cc14
-rw-r--r--konqueror/keditbookmarks/commands.cpp2
-rw-r--r--konqueror/keditbookmarks/listview.cpp10
-rw-r--r--konqueror/keditbookmarks/listview.h6
-rw-r--r--konqueror/konq_actions.cc18
-rw-r--r--konqueror/konq_actions.h2
-rw-r--r--konqueror/konq_combo.cc6
-rw-r--r--konqueror/konq_frame.cc8
-rw-r--r--konqueror/konq_guiclients.cc2
-rw-r--r--konqueror/konq_tabs.cc8
-rw-r--r--konqueror/konq_view.cc40
-rw-r--r--konqueror/konq_view.h8
-rw-r--r--konqueror/konq_viewmgr.cc4
-rw-r--r--konqueror/kttsplugin/khtmlkttsd.cpp4
-rw-r--r--konqueror/listview/konq_infolistviewitem.cc4
-rw-r--r--konqueror/listview/konq_infolistviewitem.h2
-rw-r--r--konqueror/listview/konq_listview.cc2
-rw-r--r--konqueror/listview/konq_listviewitems.cc10
-rw-r--r--konqueror/listview/konq_listviewitems.h2
-rw-r--r--konqueror/listview/konq_listviewwidget.cc4
-rw-r--r--konqueror/listview/konq_listviewwidget.h2
-rw-r--r--konqueror/listview/konq_textviewitem.cc4
-rw-r--r--konqueror/listview/konq_textviewitem.h2
-rw-r--r--konqueror/sidebar/sidebar_widget.cpp30
-rw-r--r--konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp4
-rw-r--r--konqueror/sidebar/trees/dirtree_module/dirtree_item.h2
-rw-r--r--konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp4
-rw-r--r--konqueror/sidebar/trees/history_module/history_item.cpp4
-rw-r--r--konqueror/sidebar/trees/history_module/history_item.h2
-rw-r--r--konqueror/sidebar/trees/konq_sidebartree.cpp2
-rw-r--r--konqueror/sidebar/trees/konqsidebar_tree.cpp2
33 files changed, 274 insertions, 274 deletions
diff --git a/konqueror/about/konq_aboutpage.cc b/konqueror/about/konq_aboutpage.cc
index 055ffb683..2f42405d8 100644
--- a/konqueror/about/konq_aboutpage.cc
+++ b/konqueror/about/konq_aboutpage.cc
@@ -110,11 +110,11 @@ TQString KonqAboutPageFactory::launch()
TQString home_folder = TQDir::homeDirPath();
TQString continue_icon_path = TQApplication::reverseLayout()?iconloader->iconPath("1leftarrow", KIcon::Small ):iconloader->iconPath("1rightarrow", KIcon::Small );
- res = res.tqarg( locate( "data", "kdeui/about/kde_infopage.css" ) );
+ res = res.arg( locate( "data", "kdeui/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- res = res.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
+ res = res.arg( "@import \"%1\";" ).arg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
else
- res = res.tqarg( "" );
+ res = res.arg( "" );
// Try to split page in three. If it succeeds, insert the default search into the middle part.
TQStringList parts = TQStringList::split( "<!--search bar splitter-->", res );
@@ -123,56 +123,56 @@ TQString KonqAboutPageFactory::launch()
config.setGroup( "General" );
TQString name = config.readEntry("DefaultSearchEngine");
KService::Ptr service =
- KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").tqarg(name));
+ KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").arg(name));
if ( service ) {
TQString searchBar = parts[1];
searchBar = searchBar
- .tqarg( iconSize ).tqarg( iconSize )
- .tqarg( service->name() )
- .tqarg( service->property("Keys").toStringList()[0] )
+ .arg( iconSize ).arg( iconSize )
+ .arg( service->name() )
+ .arg( service->property("Keys").toStringList()[0] )
;
res = parts[0] + searchBar + parts[2];
}
else res = parts[0] + parts[2];
}
- res = res.tqarg( i18n("Conquer your Desktop!") )
- .tqarg( i18n( "Konqueror" ) )
- .tqarg( i18n("Conquer your Desktop!") )
- .tqarg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
- .tqarg( i18n( "Starting Points" ) )
- .tqarg( i18n( "Introduction" ) )
- .tqarg( i18n( "Tips" ) )
- .tqarg( i18n( "Specifications" ) )
- .tqarg( home_folder )
- .tqarg( home_icon_path )
- .tqarg(iconSize).tqarg(iconSize)
- .tqarg( home_folder )
- .tqarg( i18n( "Home Folder" ) )
- .tqarg( i18n( "Your personal files" ) )
- .tqarg( storage_icon_path )
- .tqarg(iconSize).tqarg(iconSize)
- .tqarg( i18n( "Storage Media" ) )
- .tqarg( i18n( "Disks and removable media" ) )
- .tqarg( remote_icon_path )
- .tqarg(iconSize).tqarg(iconSize)
- .tqarg( i18n( "Network Folders" ) )
- .tqarg( i18n( "Shared files and folders" ) )
- .tqarg( wastebin_icon_path )
- .tqarg(iconSize).tqarg(iconSize)
- .tqarg( i18n( "Trash" ) )
- .tqarg( i18n( "Browse and restore the trash" ) )
- .tqarg( applications_icon_path )
- .tqarg(iconSize).tqarg(iconSize)
- .tqarg( i18n( "Applications" ) )
- .tqarg( i18n( "Installed programs" ) )
- .tqarg( help_icon_path )
- .tqarg(iconSize).tqarg(iconSize)
- .tqarg( i18n( "About Kubuntu" ) )
- .tqarg( i18n( "<a href=\"help:/kubuntu/\">Kubuntu Documentation</a>" ) )
- .tqarg( continue_icon_path )
- .tqarg( KIcon::SizeSmall ).tqarg( KIcon::SizeSmall )
- .tqarg( i18n( "Next: An Introduction to Konqueror" ) )
+ res = res.arg( i18n("Conquer your Desktop!") )
+ .arg( i18n( "Konqueror" ) )
+ .arg( i18n("Conquer your Desktop!") )
+ .arg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
+ .arg( i18n( "Starting Points" ) )
+ .arg( i18n( "Introduction" ) )
+ .arg( i18n( "Tips" ) )
+ .arg( i18n( "Specifications" ) )
+ .arg( home_folder )
+ .arg( home_icon_path )
+ .arg(iconSize).arg(iconSize)
+ .arg( home_folder )
+ .arg( i18n( "Home Folder" ) )
+ .arg( i18n( "Your personal files" ) )
+ .arg( storage_icon_path )
+ .arg(iconSize).arg(iconSize)
+ .arg( i18n( "Storage Media" ) )
+ .arg( i18n( "Disks and removable media" ) )
+ .arg( remote_icon_path )
+ .arg(iconSize).arg(iconSize)
+ .arg( i18n( "Network Folders" ) )
+ .arg( i18n( "Shared files and folders" ) )
+ .arg( wastebin_icon_path )
+ .arg(iconSize).arg(iconSize)
+ .arg( i18n( "Trash" ) )
+ .arg( i18n( "Browse and restore the trash" ) )
+ .arg( applications_icon_path )
+ .arg(iconSize).arg(iconSize)
+ .arg( i18n( "Applications" ) )
+ .arg( i18n( "Installed programs" ) )
+ .arg( help_icon_path )
+ .arg(iconSize).arg(iconSize)
+ .arg( i18n( "About Kubuntu" ) )
+ .arg( i18n( "<a href=\"help:/kubuntu/\">Kubuntu Documentation</a>" ) )
+ .arg( continue_icon_path )
+ .arg( KIcon::SizeSmall ).arg( KIcon::SizeSmall )
+ .arg( i18n( "Next: An Introduction to Konqueror" ) )
;
i18n("Search the Web");//i18n for possible future use
@@ -195,42 +195,42 @@ TQString KonqAboutPageFactory::intro()
TQString gohome_icon_path = iconloader->iconPath("gohome", KIcon::Small );
TQString continue_icon_path = TQApplication::reverseLayout()?iconloader->iconPath("1leftarrow", KIcon::Small ):iconloader->iconPath("1rightarrow", KIcon::Small );
- res = res.tqarg( locate( "data", "kdeui/about/kde_infopage.css" ) );
+ res = res.arg( locate( "data", "kdeui/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- res = res.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
+ res = res.arg( "@import \"%1\";" ).arg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
else
- res = res.tqarg( "" );
-
- res = res.tqarg( i18n("Conquer your Desktop!") )
- .tqarg( i18n( "Konqueror" ) )
- .tqarg( i18n( "Conquer your Desktop!") )
- .tqarg( i18n( "Konqueror is your file manager, web browser and universal document viewer.") )
- .tqarg( i18n( "Starting Points" ) )
- .tqarg( i18n( "Introduction" ) )
- .tqarg( i18n( "Tips" ) )
- .tqarg( i18n( "Specifications" ) )
- .tqarg( i18n( "Konqueror makes working with and managing your files easy. You can browse "
+ res = res.arg( "" );
+
+ res = res.arg( i18n("Conquer your Desktop!") )
+ .arg( i18n( "Konqueror" ) )
+ .arg( i18n( "Conquer your Desktop!") )
+ .arg( i18n( "Konqueror is your file manager, web browser and universal document viewer.") )
+ .arg( i18n( "Starting Points" ) )
+ .arg( i18n( "Introduction" ) )
+ .arg( i18n( "Tips" ) )
+ .arg( i18n( "Specifications" ) )
+ .arg( i18n( "Konqueror makes working with and managing your files easy. You can browse "
"both local and networked folders while enjoying advanced features "
"such as the powerful sidebar and file previews."
) )
- .tqarg( i18n( "Konqueror is also a full featured and easy to use web browser which you "
+ .arg( i18n( "Konqueror is also a full featured and easy to use web browser which you "
"can use to explore the Internet. "
"Enter the address (e.g. <a href=\"http://www.kde.org\">http://www.kde.org</A>) "
"of a web page you would like to visit in the location bar and press Enter, "
"or choose an entry from the Bookmarks menu.") )
- .tqarg( i18n( "To return to the previous "
+ .arg( i18n( "To return to the previous "
"location, press the back button <img width='16' height='16' src=\"%1\"> "
- "in the toolbar. ").tqarg( back_icon_path ) )
- .tqarg( i18n( "To quickly go to your Home folder press the "
- " home button <img width='16' height='16' src=\"%1\">." ).tqarg(gohome_icon_path) )
- .tqarg( i18n( "For more detailed documentation on Konqueror click <a href=\"%1\">here</a>." )
- .tqarg("exec:/khelpcenter") )
- .tqarg( i18n( "<em>Tuning Tip:</em> If you want the Konqueror web browser to start faster,"
+ "in the toolbar. ").arg( back_icon_path ) )
+ .arg( i18n( "To quickly go to your Home folder press the "
+ " home button <img width='16' height='16' src=\"%1\">." ).arg(gohome_icon_path) )
+ .arg( i18n( "For more detailed documentation on Konqueror click <a href=\"%1\">here</a>." )
+ .arg("exec:/khelpcenter") )
+ .arg( i18n( "<em>Tuning Tip:</em> If you want the Konqueror web browser to start faster,"
" you can turn off this information screen by clicking <a href=\"%1\">here</a>. You can re-enable it"
" by choosing the Help -> Konqueror Introduction menu option, and then pressing "
- "Settings -> Save View Profile \"Web Browsing\".").tqarg("config:/disable_overview") )
- .tqarg( "<img width='16' height='16' src=\"%1\">" ).tqarg( continue_icon_path )
- .tqarg( i18n( "Next: Tips &amp; Tricks" ) )
+ "Settings -> Save View Profile \"Web Browsing\".").arg("config:/disable_overview") )
+ .arg( "<img width='16' height='16' src=\"%1\">" ).arg( continue_icon_path )
+ .arg( i18n( "Next: Tips &amp; Tricks" ) )
;
@@ -250,69 +250,69 @@ TQString KonqAboutPageFactory::specs()
if ( res.isEmpty() )
return res;
- res = res.tqarg( locate( "data", "kdeui/about/kde_infopage.css" ) );
+ res = res.arg( locate( "data", "kdeui/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- res = res.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
+ res = res.arg( "@import \"%1\";" ).arg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
else
- res = res.tqarg( "" );
-
- res = res.tqarg( i18n("Conquer your Desktop!") )
- .tqarg( i18n( "Konqueror" ) )
- .tqarg( i18n("Conquer your Desktop!") )
- .tqarg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
- .tqarg( i18n( "Starting Points" ) )
- .tqarg( i18n( "Introduction" ) )
- .tqarg( i18n( "Tips" ) )
- .tqarg( i18n( "Specifications" ) )
- .tqarg( i18n("Specifications") )
- .tqarg( i18n("Konqueror is designed to embrace and support Internet standards. "
+ res = res.arg( "" );
+
+ res = res.arg( i18n("Conquer your Desktop!") )
+ .arg( i18n( "Konqueror" ) )
+ .arg( i18n("Conquer your Desktop!") )
+ .arg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
+ .arg( i18n( "Starting Points" ) )
+ .arg( i18n( "Introduction" ) )
+ .arg( i18n( "Tips" ) )
+ .arg( i18n( "Specifications" ) )
+ .arg( i18n("Specifications") )
+ .arg( i18n("Konqueror is designed to embrace and support Internet standards. "
"The aim is to fully implement the officially sanctioned standards "
"from organizations such as the W3 and OASIS, while also adding "
"extra support for other common usability features that arise as "
"de facto standards across the Internet. Along with this support, "
"for such functions as favicons, Internet Keywords, and <A HREF=\"%1\">XBEL bookmarks</A>, "
- "Konqueror also implements:").tqarg("http://pyxml.sourceforge.net/topics/xbel/") )
- .tqarg( i18n("Web Browsing") )
- .tqarg( i18n("Supported standards") )
- .tqarg( i18n("Additional requirements*") )
- .tqarg( i18n("<A HREF=\"%1\">DOM</A> (Level 1, partially Level 2) based "
- "<A HREF=\"%2\">HTML 4.01</A>").tqarg("http://www.w3.org/DOM").tqarg("http://www.w3.org/TR/html4/") )
- .tqarg( i18n("built-in") )
- .tqarg( i18n("<A HREF=\"%1\">Cascading Style Sheets</A> (CSS 1, partially CSS 2)").tqarg("http://www.w3.org/Style/CSS/") )
- .tqarg( i18n("built-in") )
- .tqarg( i18n("<A HREF=\"%1\">ECMA-262</A> Edition 3 (roughly equals JavaScript 1.5)").tqarg("http://www.ecma.ch/ecma1/STAND/ECMA-262.HTM") )
- .tqarg( i18n("JavaScript disabled (globally). Enable JavaScript <A HREF=\"%1\">here</A>.").tqarg("exec:/kcmshell khtml_java_js") )
- .tqarg( i18n("JavaScript enabled (globally). Configure JavaScript <A HREF=\\\"%1\\\">here</A>.").tqarg("exec:/kcmshell khtml_java_js") ) // leave the double backslashes here, they are necessary for javascript !
- .tqarg( i18n("Secure <A HREF=\"%1\">Java</A><SUP>&reg;</SUP> support").tqarg("http://java.sun.com") )
- .tqarg( i18n("JDK 1.2.0 (Java 2) compatible VM (<A HREF=\"%1\">Blackdown</A>, <A HREF=\"%2\">IBM</A> or <A HREF=\"%3\">Sun</A>)")
- .tqarg("http://www.blackdown.org").tqarg("http://www.ibm.com").tqarg("http://java.sun.com") )
- .tqarg( i18n("Enable Java (globally) <A HREF=\"%1\">here</A>.").tqarg("exec:/kcmshell khtml_java_js") ) // TODO Maybe test if Java is enabled ?
- .tqarg( i18n("Netscape Communicator<SUP>&reg;</SUP> <A HREF=\"%4\">plugins</A> (for viewing <A HREF=\"%1\">Flash<SUP>&reg;</SUP></A>, <A HREF=\"%2\">Real<SUP>&reg;</SUP></A>Audio, <A HREF=\"%3\">Real<SUP>&reg;</SUP></A>Video, etc.)")
- .tqarg("http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash")
- .tqarg("http://www.real.com").tqarg("http://www.real.com")
- .tqarg("about:plugins") )
- .tqarg( i18n("built-in") )
- .tqarg( i18n("Secure Sockets Layer") )
- .tqarg( i18n("(TLS/SSL v2/3) for secure communications up to 168bit") )
- .tqarg( i18n("OpenSSL") )
- .tqarg( i18n("Bidirectional 16bit tqunicode support") )
- .tqarg( i18n("built-in") )
- .tqarg( i18n("AutoCompletion for forms") )
- .tqarg( i18n("built-in") )
- .tqarg( i18n("G E N E R A L") )
- .tqarg( i18n("Feature") )
- .tqarg( i18n("Details") )
- .tqarg( i18n("Image formats") )
- .tqarg( i18n("Transfer protocols") )
- .tqarg( i18n("HTTP 1.1 (including gzip/bzip2 compression)") )
- .tqarg( i18n("FTP") )
- .tqarg( i18n("and <A HREF=\"%1\">many more...</A>").tqarg("exec:/kcmshell ioslaveinfo") )
- .tqarg( i18n("URL-Completion") )
- .tqarg( i18n("Manual"))
- .tqarg( i18n("Popup"))
- .tqarg( i18n("(Short-) Automatic"))
- .tqarg( "<img width='16' height='16' src=\"%1\">" ).tqarg( continue_icon_path )
- .tqarg( i18n("<a href=\"%1\">Return to Starting Points</a>").tqarg("launch.html") )
+ "Konqueror also implements:").arg("http://pyxml.sourceforge.net/topics/xbel/") )
+ .arg( i18n("Web Browsing") )
+ .arg( i18n("Supported standards") )
+ .arg( i18n("Additional requirements*") )
+ .arg( i18n("<A HREF=\"%1\">DOM</A> (Level 1, partially Level 2) based "
+ "<A HREF=\"%2\">HTML 4.01</A>").arg("http://www.w3.org/DOM").arg("http://www.w3.org/TR/html4/") )
+ .arg( i18n("built-in") )
+ .arg( i18n("<A HREF=\"%1\">Cascading Style Sheets</A> (CSS 1, partially CSS 2)").arg("http://www.w3.org/Style/CSS/") )
+ .arg( i18n("built-in") )
+ .arg( i18n("<A HREF=\"%1\">ECMA-262</A> Edition 3 (roughly equals JavaScript 1.5)").arg("http://www.ecma.ch/ecma1/STAND/ECMA-262.HTM") )
+ .arg( i18n("JavaScript disabled (globally). Enable JavaScript <A HREF=\"%1\">here</A>.").arg("exec:/kcmshell khtml_java_js") )
+ .arg( i18n("JavaScript enabled (globally). Configure JavaScript <A HREF=\\\"%1\\\">here</A>.").arg("exec:/kcmshell khtml_java_js") ) // leave the double backslashes here, they are necessary for javascript !
+ .arg( i18n("Secure <A HREF=\"%1\">Java</A><SUP>&reg;</SUP> support").arg("http://java.sun.com") )
+ .arg( i18n("JDK 1.2.0 (Java 2) compatible VM (<A HREF=\"%1\">Blackdown</A>, <A HREF=\"%2\">IBM</A> or <A HREF=\"%3\">Sun</A>)")
+ .arg("http://www.blackdown.org").arg("http://www.ibm.com").arg("http://java.sun.com") )
+ .arg( i18n("Enable Java (globally) <A HREF=\"%1\">here</A>.").arg("exec:/kcmshell khtml_java_js") ) // TODO Maybe test if Java is enabled ?
+ .arg( i18n("Netscape Communicator<SUP>&reg;</SUP> <A HREF=\"%4\">plugins</A> (for viewing <A HREF=\"%1\">Flash<SUP>&reg;</SUP></A>, <A HREF=\"%2\">Real<SUP>&reg;</SUP></A>Audio, <A HREF=\"%3\">Real<SUP>&reg;</SUP></A>Video, etc.)")
+ .arg("http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash")
+ .arg("http://www.real.com").arg("http://www.real.com")
+ .arg("about:plugins") )
+ .arg( i18n("built-in") )
+ .arg( i18n("Secure Sockets Layer") )
+ .arg( i18n("(TLS/SSL v2/3) for secure communications up to 168bit") )
+ .arg( i18n("OpenSSL") )
+ .arg( i18n("Bidirectional 16bit tqunicode support") )
+ .arg( i18n("built-in") )
+ .arg( i18n("AutoCompletion for forms") )
+ .arg( i18n("built-in") )
+ .arg( i18n("G E N E R A L") )
+ .arg( i18n("Feature") )
+ .arg( i18n("Details") )
+ .arg( i18n("Image formats") )
+ .arg( i18n("Transfer protocols") )
+ .arg( i18n("HTTP 1.1 (including gzip/bzip2 compression)") )
+ .arg( i18n("FTP") )
+ .arg( i18n("and <A HREF=\"%1\">many more...</A>").arg("exec:/kcmshell ioslaveinfo") )
+ .arg( i18n("URL-Completion") )
+ .arg( i18n("Manual"))
+ .arg( i18n("Popup"))
+ .arg( i18n("(Short-) Automatic"))
+ .arg( "<img width='16' height='16' src=\"%1\">" ).arg( continue_icon_path )
+ .arg( i18n("<a href=\"%1\">Return to Starting Points</a>").arg("launch.html") )
;
@@ -347,57 +347,57 @@ TQString KonqAboutPageFactory::tips()
iconloader->iconPath("view_left_right", KIcon::Small );
TQString continue_icon_path = TQApplication::reverseLayout()?iconloader->iconPath("1leftarrow", KIcon::Small ):iconloader->iconPath("1rightarrow", KIcon::Small );
- res = res.tqarg( locate( "data", "kdeui/about/kde_infopage.css" ) );
+ res = res.arg( locate( "data", "kdeui/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- res = res.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
+ res = res.arg( "@import \"%1\";" ).arg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
else
- res = res.tqarg( "" );
-
- res = res.tqarg( i18n("Conquer your Desktop!") )
- .tqarg( i18n( "Konqueror" ) )
- .tqarg( i18n("Conquer your Desktop!") )
- .tqarg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
- .tqarg( i18n( "Starting Points" ) )
- .tqarg( i18n( "Introduction" ) )
- .tqarg( i18n( "Tips" ) )
- .tqarg( i18n( "Specifications" ) )
- .tqarg( i18n( "Tips &amp; Tricks" ) )
- .tqarg( i18n( "Use Internet-Keywords and Web-Shortcuts: by typing \"gg: KDE\" one can search the Internet, "
+ res = res.arg( "" );
+
+ res = res.arg( i18n("Conquer your Desktop!") )
+ .arg( i18n( "Konqueror" ) )
+ .arg( i18n("Conquer your Desktop!") )
+ .arg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
+ .arg( i18n( "Starting Points" ) )
+ .arg( i18n( "Introduction" ) )
+ .arg( i18n( "Tips" ) )
+ .arg( i18n( "Specifications" ) )
+ .arg( i18n( "Tips &amp; Tricks" ) )
+ .arg( i18n( "Use Internet-Keywords and Web-Shortcuts: by typing \"gg: KDE\" one can search the Internet, "
"using Google, for the search phrase \"KDE\". There are a lot of "
"Web-Shortcuts predefined to make searching for software or looking "
"up certain words in an encyclopedia a breeze. You can even "
- "<a href=\"%1\">create your own</a> Web-Shortcuts." ).tqarg("exec:/kcmshell ebrowsing") )
- .tqarg( i18n( "Use the magnifier button <img width='16' height='16' src=\"%1\"> in the"
- " toolbar to increase the font size on your web page.").tqarg(viewmag_icon_path) )
- .tqarg( i18n( "When you want to paste a new address into the Location toolbar you might want to "
+ "<a href=\"%1\">create your own</a> Web-Shortcuts." ).arg("exec:/kcmshell ebrowsing") )
+ .arg( i18n( "Use the magnifier button <img width='16' height='16' src=\"%1\"> in the"
+ " toolbar to increase the font size on your web page.").arg(viewmag_icon_path) )
+ .arg( i18n( "When you want to paste a new address into the Location toolbar you might want to "
"clear the current entry by pressing the black arrow with the white cross "
"<img width='16' height='16' src=\"%1\"> in the toolbar.")
- .tqarg(TQApplication::reverseLayout() ? locationbar_erase_rtl_icon_path : locationbar_erase_icon_path))
- .tqarg( i18n( "To create a link on your desktop pointing to the current page, "
+ .arg(TQApplication::reverseLayout() ? locationbar_erase_rtl_icon_path : locationbar_erase_icon_path))
+ .arg( i18n( "To create a link on your desktop pointing to the current page, "
"simply drag the \"Location\" label that is to the left of the Location toolbar, drop it on to "
"the desktop, and choose \"Link\"." ) )
- .tqarg( i18n( "You can also find <img width='16' height='16' src=\"%1\"> \"Full-Screen Mode\" "
+ .arg( i18n( "You can also find <img width='16' height='16' src=\"%1\"> \"Full-Screen Mode\" "
"in the Settings menu. This feature is very useful for \"Talk\" "
- "sessions.").tqarg(window_fullscreen_icon_path) )
- .tqarg( i18n( "Divide et impera (lat. \"Divide and conquer\") - by splitting a window "
+ "sessions.").arg(window_fullscreen_icon_path) )
+ .arg( i18n( "Divide et impera (lat. \"Divide and conquer\") - by splitting a window "
"into two parts (e.g. Window -> <img width='16' height='16' src=\"%1\"> Split View "
"Left/Right) you can make Konqueror appear the way you like. You"
" can even load some example view-profiles (e.g. Midnight Commander)"
- ", or create your own ones." ).tqarg(view_left_right_icon_path))
- .tqarg( i18n( "Use the <a href=\"%1\">user-agent</a> feature if the website you are visiting "
+ ", or create your own ones." ).arg(view_left_right_icon_path))
+ .arg( i18n( "Use the <a href=\"%1\">user-agent</a> feature if the website you are visiting "
"asks you to use a different browser "
- "(and do not forget to send a complaint to the webmaster!)" ).tqarg("exec:/kcmshell useragent") )
- .tqarg( i18n( "The <img width='16' height='16' src=\"%1\"> History in your SideBar ensures "
- "that you can keep track of the pages you have visited recently.").tqarg(history_icon_path) )
- .tqarg( i18n( "Use a caching <a href=\"%1\">proxy</a> to speed up your"
- " Internet connection.").tqarg("exec:/kcmshell proxy") )
- .tqarg( i18n( "Advanced users will appreciate the Konsole which you can embed into "
+ "(and do not forget to send a complaint to the webmaster!)" ).arg("exec:/kcmshell useragent") )
+ .arg( i18n( "The <img width='16' height='16' src=\"%1\"> History in your SideBar ensures "
+ "that you can keep track of the pages you have visited recently.").arg(history_icon_path) )
+ .arg( i18n( "Use a caching <a href=\"%1\">proxy</a> to speed up your"
+ " Internet connection.").arg("exec:/kcmshell proxy") )
+ .arg( i18n( "Advanced users will appreciate the Konsole which you can embed into "
"Konqueror (Window -> <img width='16' height='16' SRC=\"%1\"> Show "
- "Terminal Emulator).").tqarg(openterm_icon_path))
- .tqarg( i18n( "Thanks to <a href=\"%1\">DCOP</a> you can have full control over Konqueror using a script."
-).tqarg("exec:/kdcop") )
- .tqarg( i18n( "<img width='16' height='16' src=\"%1\">" ).tqarg( continue_icon_path ) )
- .tqarg( i18n( "Next: Specifications" ) )
+ "Terminal Emulator).").arg(openterm_icon_path))
+ .arg( i18n( "Thanks to <a href=\"%1\">DCOP</a> you can have full control over Konqueror using a script."
+).arg("exec:/kdcop") )
+ .arg( i18n( "<img width='16' height='16' src=\"%1\">" ).arg( continue_icon_path ) )
+ .arg( i18n( "Next: Specifications" ) )
;
@@ -413,10 +413,10 @@ TQString KonqAboutPageFactory::plugins()
return *s_plugins_html;
TQString res = loadFile( locate( "data", kapp->reverseLayout() ? "konqueror/about/plugins_rtl.html" : "konqueror/about/plugins.html" ))
- .tqarg(i18n("Installed Plugins"))
- .tqarg(i18n("<td>Plugin</td><td>Description</td><td>File</td><td>Types</td>"))
- .tqarg(i18n("Installed"))
- .tqarg(i18n("<td>Mime Type</td><td>Description</td><td>Suffixes</td><td>Plugin</td>"));
+ .arg(i18n("Installed Plugins"))
+ .arg(i18n("<td>Plugin</td><td>Description</td><td>File</td><td>Types</td>"))
+ .arg(i18n("Installed"))
+ .arg(i18n("<td>Mime Type</td><td>Description</td><td>Suffixes</td><td>Plugin</td>"));
if ( res.isEmpty() )
return res;
@@ -489,7 +489,7 @@ void KonqAboutPage::restoreState( TQDataStream &stream )
void KonqAboutPage::serve( const TQString& html, const TQString& what )
{
m_what = what;
- begin( KURL( TQString("about:%1").tqarg(what) ) );
+ begin( KURL( TQString("about:%1").arg(what) ) );
write( html );
end();
m_htmlDoc = html;
diff --git a/konqueror/client/kfmclient.cc b/konqueror/client/kfmclient.cc
index 807e87e57..60a384102 100644
--- a/konqueror/client/kfmclient.cc
+++ b/konqueror/client/kfmclient.cc
@@ -404,7 +404,7 @@ bool clientApp::openProfile( const TQString & profileName, const TQString & url,
TQString profile = locate( "data", TQString::fromLatin1("konqueror/profiles/") + profileName );
if ( profile.isEmpty() )
{
- fprintf( stderr, "%s", i18n("Profile %1 not found\n").tqarg(profileName).local8Bit().data() );
+ fprintf( stderr, "%s", i18n("Profile %1 not found\n").arg(profileName).local8Bit().data() );
::exit( 0 );
}
KonquerorIface_stub konqy( appId, "KonquerorIface" );
@@ -630,7 +630,7 @@ bool clientApp::doIt()
}
else
{
- fprintf( stderr, "%s", i18n("Syntax Error: Unknown command '%1'\n").tqarg(TQString::fromLocal8Bit(command)).local8Bit().data() );
+ fprintf( stderr, "%s", i18n("Syntax Error: Unknown command '%1'\n").arg(TQString::fromLocal8Bit(command)).local8Bit().data() );
return false;
}
return true;
diff --git a/konqueror/keditbookmarks/commands.cpp b/konqueror/keditbookmarks/commands.cpp
index f0855fec0..2ad58a682 100644
--- a/konqueror/keditbookmarks/commands.cpp
+++ b/konqueror/keditbookmarks/commands.cpp
@@ -218,7 +218,7 @@ void CreateCommand::unexecute() {
KBookmark bk = CurrentMgr::bookmarkAt(m_to);
Q_ASSERT(!bk.isNull() && !bk.parentGroup().isNull());
- ListView::self()->tqinvalidate(bk.address());
+ ListView::self()->invalidate(bk.address());
bk.parentGroup().deleteBookmark(bk);
}
diff --git a/konqueror/keditbookmarks/listview.cpp b/konqueror/keditbookmarks/listview.cpp
index 62702a1c3..1fa31e967 100644
--- a/konqueror/keditbookmarks/listview.cpp
+++ b/konqueror/keditbookmarks/listview.cpp
@@ -158,12 +158,12 @@ TQValueList<KBookmark> ListView::itemsToBookmarks(const TQValueVector<KEBListVie
return bookmarks;
}
-void ListView::tqinvalidate(const TQString & address)
+void ListView::invalidate(const TQString & address)
{
- tqinvalidate(getItemAtAddress(address));
+ invalidate(getItemAtAddress(address));
}
-void ListView::tqinvalidate(TQListViewItem * item)
+void ListView::invalidate(TQListViewItem * item)
{
if(item->isSelected())
{
@@ -181,7 +181,7 @@ void ListView::tqinvalidate(TQListViewItem * item)
TQListViewItem * child = item->firstChild();
while(child)
{
- //tqinvalidate(child);
+ //invalidate(child);
child = child->nextSibling();
}
}
@@ -277,7 +277,7 @@ void ListView::deselectAllChildren(KEBListViewItem *item)
else
deselectAllChildren(child);
}
- child->tqrepaint();
+ child->repaint();
child = static_cast<KEBListViewItem *>(child->nextSibling());
}
}
diff --git a/konqueror/keditbookmarks/listview.h b/konqueror/keditbookmarks/listview.h
index c05226ff6..7ffe76c37 100644
--- a/konqueror/keditbookmarks/listview.h
+++ b/konqueror/keditbookmarks/listview.h
@@ -56,7 +56,7 @@ public:
void setTmpStatus(const TQString &);
void restoreStatus();
- void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment);
void setSelected ( bool s );
virtual void setOpen(bool);
@@ -140,8 +140,8 @@ public:
// selected item stuff
void selected(KEBListViewItem * item, bool s);
- void tqinvalidate(const TQString & address);
- void tqinvalidate(TQListViewItem * item);
+ void invalidate(const TQString & address);
+ void invalidate(TQListViewItem * item);
void fixUpCurrent(const TQString & address);
KEBListViewItem * firstSelected() const;
diff --git a/konqueror/konq_actions.cc b/konqueror/konq_actions.cc
index e60761b9c..df25a5e6c 100644
--- a/konqueror/konq_actions.cc
+++ b/konqueror/konq_actions.cc
@@ -48,12 +48,12 @@ void KonqBidiHistoryAction::fillHistoryPopup( const TQPtrList<HistoryEntry> &his
{
assert ( popup ); // kill me if this 0... :/
- //kdDebug(1202) << "fillHistoryPopup position: " << history.tqat() << endl;
+ //kdDebug(1202) << "fillHistoryPopup position: " << history.at() << endl;
HistoryEntry * current = history.current();
TQPtrListIterator<HistoryEntry> it( history );
if (onlyBack || onlyForward)
{
- it += history.tqat(); // Jump to current item
+ it += history.at(); // Jump to current item
if ( !onlyForward ) --it; else ++it; // And move off it
} else if ( startPos )
it += startPos; // Jump to specified start pos
@@ -75,7 +75,7 @@ void KonqBidiHistoryAction::fillHistoryPopup( const TQPtrList<HistoryEntry> &his
break;
if ( !onlyForward ) --it; else ++it;
}
- //kdDebug(1202) << "After fillHistoryPopup position: " << history.tqat() << endl;
+ //kdDebug(1202) << "After fillHistoryPopup position: " << history.at() << endl;
}
///////////////////////////////
@@ -116,7 +116,7 @@ void KonqBidiHistoryAction::fillGoMenu( const TQPtrList<HistoryEntry> & history
if (history.isEmpty())
return; // nothing to do
- //kdDebug(1202) << "fillGoMenu position: " << history.tqat() << endl;
+ //kdDebug(1202) << "fillGoMenu position: " << history.at() << endl;
if ( m_firstIndex == 0 ) // should never happen since done in plug
m_firstIndex = m_goMenu->count();
else
@@ -136,10 +136,10 @@ void KonqBidiHistoryAction::fillGoMenu( const TQPtrList<HistoryEntry> & history
// Second case: big history, in one or both directions
{
// Assume both directions first (in this case we place the current URL in the middle)
- m_startPos = history.tqat() + 4;
+ m_startPos = history.at() + 4;
// Forward not big enough ?
- if ( history.tqat() > (int)history.count() - 4 )
+ if ( history.at() > (int)history.count() - 4 )
m_startPos = history.count() - 1;
}
Q_ASSERT( m_startPos >= 0 && (uint)m_startPos < history.count() );
@@ -148,7 +148,7 @@ void KonqBidiHistoryAction::fillGoMenu( const TQPtrList<HistoryEntry> & history
kdWarning() << "m_startPos=" << m_startPos << " history.count()=" << history.count() << endl;
return;
}
- m_currentPos = history.tqat(); // for slotActivated
+ m_currentPos = history.at(); // for slotActivated
KonqBidiHistoryAction::fillHistoryPopup( history, m_goMenu, false, false, true, m_startPos );
}
@@ -444,7 +444,7 @@ void KonqMostOftenURLSAction::slotFillMenu()
m_popupList.clear();
int id = s_mostEntries->count() -1;
- KonqHistoryEntry *entry = s_mostEntries->tqat( id );
+ KonqHistoryEntry *entry = s_mostEntries->at( id );
while ( entry ) {
// we take either title, typedURL or URL (in this order)
TQString text = entry->title.isEmpty() ? (entry->typedURL.isEmpty() ?
@@ -459,7 +459,7 @@ void KonqMostOftenURLSAction::slotFillMenu()
// This prevents crashes when another process tells us to remove an entry.
m_popupList.prepend( entry->url );
- entry = (id > 0) ? s_mostEntries->tqat( --id ) : 0L;
+ entry = (id > 0) ? s_mostEntries->at( --id ) : 0L;
}
setEnabled( !s_mostEntries->isEmpty() );
Q_ASSERT( s_mostEntries->count() == m_popupList.count() );
diff --git a/konqueror/konq_actions.h b/konqueror/konq_actions.h
index 41dbdad71..849d45668 100644
--- a/konqueror/konq_actions.h
+++ b/konqueror/konq_actions.h
@@ -62,7 +62,7 @@ signals:
private:
uint m_firstIndex; // first index in the Go menu
int m_startPos;
- int m_currentPos; // == history.tqat()
+ int m_currentPos; // == history.at()
TQPopupMenu *m_goMenu; // hack
};
diff --git a/konqueror/konq_frame.cc b/konqueror/konq_frame.cc
index 0da7cd29a..b769184bc 100644
--- a/konqueror/konq_frame.cc
+++ b/konqueror/konq_frame.cc
@@ -352,8 +352,8 @@ void KonqFrame::printFrameInfo( const TQString& spaces )
{
TQString className = "NoPart";
if (part()) className = part()->widget()->className();
- kdDebug(1202) << spaces << "KonqFrame " << this << " visible=" << TQString("%1").tqarg(isVisible()) << " containing view "
- << childView() << " visible=" << TQString("%1").tqarg(isVisible())
+ kdDebug(1202) << spaces << "KonqFrame " << this << " visible=" << TQString("%1").arg(isVisible()) << " containing view "
+ << childView() << " visible=" << TQString("%1").arg(isVisible())
<< " and part " << part() << " whose widget is a " << className << endl;
}
@@ -463,7 +463,7 @@ KonqFrame::paintEvent( TQPaintEvent* )
#ifdef USE_QT4
#warning [INFO] Repaint call disabled in Qt4 to prevent recursive repaint (which otherwise occurs for unknown reasons)
#else // USE_QT4
- m_pStatusBar->tqrepaint();
+ m_pStatusBar->repaint();
#endif // USE_QT4
}
@@ -580,7 +580,7 @@ KonqFrameBase* KonqFrameContainer::otherChild( KonqFrameBase* child )
void KonqFrameContainer::printFrameInfo( const TQString& spaces )
{
- kdDebug(1202) << spaces << "KonqFrameContainer " << this << " visible=" << TQString("%1").tqarg(isVisible())
+ kdDebug(1202) << spaces << "KonqFrameContainer " << this << " visible=" << TQString("%1").arg(isVisible())
<< " activeChild=" << m_pActiveChild << endl;
if (!m_pActiveChild)
kdDebug(1202) << "WARNING: " << this << " has a null active child!" << endl;
diff --git a/konqueror/konq_guiclients.cc b/konqueror/konq_guiclients.cc
index b7e756971..caf909d68 100644
--- a/konqueror/konq_guiclients.cc
+++ b/konqueror/konq_guiclients.cc
@@ -191,7 +191,7 @@ ToggleViewGUIClient::ToggleViewGUIClient( KonqMainWindow *mainWindow )
TQString name = (*cIt)->desktopEntryName();
//kdDebug(1202) << "ToggleViewGUIClient: name=" << name << endl;
KToggleAction *action = new KToggleAction( description, 0, mainWindow->actionCollection(), name.latin1() );
- action->setCheckedState( i18n( "Hide %1" ).tqarg( (*cIt)->name() ) );
+ action->setCheckedState( i18n( "Hide %1" ).arg( (*cIt)->name() ) );
// HACK
if ( (*cIt)->icon() != "unknown" )
diff --git a/konqueror/konq_tabs.cc b/konqueror/konq_tabs.cc
index 457f6ed21..92ff14c4a 100644
--- a/konqueror/konq_tabs.cc
+++ b/konqueror/konq_tabs.cc
@@ -218,14 +218,14 @@ void KonqFrameTabs::copyHistory( KonqFrameBase *other )
for (uint i = 0; i < m_pChildFrameList->count(); i++ )
{
- m_pChildFrameList->tqat(i)->copyHistory( static_cast<KonqFrameTabs *>( other )->m_pChildFrameList->tqat(i) );
+ m_pChildFrameList->at(i)->copyHistory( static_cast<KonqFrameTabs *>( other )->m_pChildFrameList->at(i) );
}
}
void KonqFrameTabs::printFrameInfo( const TQString& spaces )
{
kdDebug(1202) << spaces << "KonqFrameTabs " << this << " visible="
- << TQString("%1").tqarg(isVisible()) << " activeChild="
+ << TQString("%1").arg(isVisible()) << " activeChild="
<< m_pActiveChild << endl;
if (!m_pActiveChild)
@@ -234,7 +234,7 @@ void KonqFrameTabs::printFrameInfo( const TQString& spaces )
KonqFrameBase* child;
int childFrameCount = m_pChildFrameList->count();
for (int i = 0 ; i < childFrameCount ; i++) {
- child = m_pChildFrameList->tqat(i);
+ child = m_pChildFrameList->at(i);
if (child != 0L)
child->printFrameInfo(spaces + " ");
else
@@ -346,7 +346,7 @@ void KonqFrameTabs::moveTabForward( int index )
void KonqFrameTabs::slotMovedTab( int from, int to )
{
- KonqFrameBase* fromFrame = m_pChildFrameList->tqat( from );
+ KonqFrameBase* fromFrame = m_pChildFrameList->at( from );
m_pChildFrameList->remove( fromFrame );
m_pChildFrameList->insert( to, fromFrame );
diff --git a/konqueror/konq_view.cc b/konqueror/konq_view.cc
index 4278d5522..8037b3927 100644
--- a/konqueror/konq_view.cc
+++ b/konqueror/konq_view.cc
@@ -117,7 +117,7 @@ KonqView::~KonqView()
if (part_url.isNull())
part_url = "";
TQCString line;
- line = ( TQString("close(%1):%2\n").tqarg(m_randID,0,16).tqarg(part_url) ).utf8();
+ line = ( TQString("close(%1):%2\n").arg(m_randID,0,16).arg(part_url) ).utf8();
KonqMainWindow::s_crashlog_file->writeBlock(line, line.length());
KonqMainWindow::s_crashlog_file->flush();
}
@@ -155,9 +155,9 @@ void KonqView::openURL( const KURL &url, const TQString & locationBarURL,
TQCString line;
- line = ( TQString("closed(%1):%2\n").tqarg(m_randID,0,16).tqarg(part_url) ).utf8();
+ line = ( TQString("closed(%1):%2\n").arg(m_randID,0,16).arg(part_url) ).utf8();
KonqMainWindow::s_crashlog_file->writeBlock(line,line.length());
- line = ( TQString("opened(%3):%4\n").tqarg(m_randID,0,16).tqarg(url_url) ).utf8();
+ line = ( TQString("opened(%3):%4\n").arg(m_randID,0,16).arg(url_url) ).utf8();
KonqMainWindow::s_crashlog_file->writeBlock(line,line.length());
KonqMainWindow::s_crashlog_file->flush();
}
@@ -227,7 +227,7 @@ void KonqView::openURL( const KURL &url, const TQString & locationBarURL,
KonqHistoryManager::kself()->addPending( url, locationBarURL, TQString::null);
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "Current position : " << m_lstHistory.tqat() << endl;
+ kdDebug(1202) << "Current position : " << m_lstHistory.at() << endl;
#endif
}
@@ -711,7 +711,7 @@ void KonqView::createHistoryEntry()
#ifdef DEBUG_HISTORY
kdDebug(1202) << "Truncating history" << endl;
#endif
- m_lstHistory.tqat( m_lstHistory.count() - 1 ); // go to last one
+ m_lstHistory.at( m_lstHistory.count() - 1 ); // go to last one
for ( ; m_lstHistory.current() != current ; )
{
if ( !m_lstHistory.removeLast() ) // and remove from the end (faster and easier)
@@ -720,7 +720,7 @@ void KonqView::createHistoryEntry()
// makes current() null if it's the last item. however in qt2
// the behaviour was different than the documentation. this is
// changed in qt3 to behave as documented ;-) (Simon)
- m_lstHistory.tqat( m_lstHistory.count() - 1 );
+ m_lstHistory.at( m_lstHistory.count() - 1 );
}
// Now current is the current again.
}
@@ -730,9 +730,9 @@ void KonqView::createHistoryEntry()
#endif
m_lstHistory.append( new HistoryEntry ); // made current
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "at=" << m_lstHistory.tqat() << " count=" << m_lstHistory.count() << endl;
+ kdDebug(1202) << "at=" << m_lstHistory.at() << " count=" << m_lstHistory.count() << endl;
#endif
- assert( m_lstHistory.tqat() == (int) m_lstHistory.count() - 1 );
+ assert( m_lstHistory.at() == (int) m_lstHistory.count() - 1 );
}
void KonqView::updateHistoryEntry( bool saveLocationBarURL )
@@ -752,20 +752,20 @@ void KonqView::updateHistoryEntry( bool saveLocationBarURL )
}
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "Saving part URL : " << m_pPart->url() << " in history position " << m_lstHistory.tqat() << endl;
+ kdDebug(1202) << "Saving part URL : " << m_pPart->url() << " in history position " << m_lstHistory.at() << endl;
#endif
current->url = m_pPart->url();
if (saveLocationBarURL)
{
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "Saving location bar URL : " << m_sLocationBarURL << " in history position " << m_lstHistory.tqat() << endl;
+ kdDebug(1202) << "Saving location bar URL : " << m_sLocationBarURL << " in history position " << m_lstHistory.at() << endl;
#endif
current->locationBarURL = m_sLocationBarURL;
current->pageSecurity = m_pageSecurity;
}
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "Saving title : " << m_caption << " in history position " << m_lstHistory.tqat() << endl;
+ kdDebug(1202) << "Saving title : " << m_caption << " in history position " << m_lstHistory.at() << endl;
#endif
current->title = m_caption;
current->strServiceType = m_serviceType;
@@ -800,7 +800,7 @@ void KonqView::go( int steps )
return;
}
- int newPos = m_lstHistory.tqat() + steps;
+ int newPos = m_lstHistory.at() + steps;
#ifdef DEBUG_HISTORY
kdDebug(1202) << "go : steps=" << steps
<< " newPos=" << newPos
@@ -813,13 +813,13 @@ void KonqView::go( int steps )
stop();
// Yay, we can move there without a loop !
- HistoryEntry *currentHistoryEntry = m_lstHistory.tqat( newPos ); // sets current item
+ HistoryEntry *currentHistoryEntry = m_lstHistory.at( newPos ); // sets current item
assert( currentHistoryEntry );
- assert( newPos == m_lstHistory.tqat() ); // check we moved (i.e. if I understood the docu)
+ assert( newPos == m_lstHistory.at() ); // check we moved (i.e. if I understood the docu)
assert( currentHistoryEntry == m_lstHistory.current() );
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "New position " << m_lstHistory.tqat() << endl;
+ kdDebug(1202) << "New position " << m_lstHistory.at() << endl;
#endif
restoreHistory();
@@ -866,7 +866,7 @@ void KonqView::restoreHistory()
m_pMainWindow->updateToolBarActions();
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "New position (2) " << m_lstHistory.tqat() << endl;
+ kdDebug(1202) << "New position (2) " << m_lstHistory.at() << endl;
#endif
}
@@ -874,9 +874,9 @@ const HistoryEntry * KonqView::historyAt(const int pos)
{
if(pos<0 || pos>=(int)m_lstHistory.count())
return 0L;
- int oldpos = m_lstHistory.tqat();
- const HistoryEntry* h = m_lstHistory.tqat(pos);
- m_lstHistory.tqat( oldpos );
+ int oldpos = m_lstHistory.at();
+ const HistoryEntry* h = m_lstHistory.at(pos);
+ m_lstHistory.at( oldpos );
return h;
}
@@ -887,7 +887,7 @@ void KonqView::copyHistory( KonqView *other )
TQPtrListIterator<HistoryEntry> it( other->m_lstHistory );
for (; it.current(); ++it )
m_lstHistory.append( new HistoryEntry( *it.current() ) );
- m_lstHistory.tqat(other->m_lstHistory.tqat());
+ m_lstHistory.at(other->m_lstHistory.at());
}
KURL KonqView::url() const
diff --git a/konqueror/konq_view.h b/konqueror/konq_view.h
index d251da53b..1329000f8 100644
--- a/konqueror/konq_view.h
+++ b/konqueror/konq_view.h
@@ -125,17 +125,17 @@ public:
/**
* @return true if view can go back
*/
- bool canGoBack()const { return m_lstHistory.tqat() > 0; }
+ bool canGoBack()const { return m_lstHistory.at() > 0; }
/**
* @return true if view can go forward
*/
- bool canGoForward()const { return m_lstHistory.tqat() != ((int)m_lstHistory.count())-1; }
+ bool canGoForward()const { return m_lstHistory.at() != ((int)m_lstHistory.count())-1; }
/**
* @return the position in the history
*/
- int historyPos() const { return m_lstHistory.tqat(); }
+ int historyPos() const { return m_lstHistory.at(); }
uint historyLength() { return m_lstHistory.count(); }
@@ -149,7 +149,7 @@ public:
*/
void restoreHistory();
- void setHistoryPos(int newPos) { m_lstHistory.tqat( newPos ); }
+ void setHistoryPos(int newPos) { m_lstHistory.at( newPos ); }
/**
* @return the history of this view
diff --git a/konqueror/konq_viewmgr.cc b/konqueror/konq_viewmgr.cc
index 58848efec..b57ae53bc 100644
--- a/konqueror/konq_viewmgr.cc
+++ b/konqueror/konq_viewmgr.cc
@@ -1611,8 +1611,8 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
if (cfg.readBoolEntry( TQString::fromLatin1( "docContainer" ).prepend( prefix ), false ))
m_pDocContainer = newContainer;
- loadItem( cfg, newContainer, childList.tqat(0), defaultURL, openURL );
- loadItem( cfg, newContainer, childList.tqat(1), defaultURL, openURL );
+ loadItem( cfg, newContainer, childList.at(0), defaultURL, openURL );
+ loadItem( cfg, newContainer, childList.at(1), defaultURL, openURL );
newContainer->setSizes( sizes );
diff --git a/konqueror/kttsplugin/khtmlkttsd.cpp b/konqueror/kttsplugin/khtmlkttsd.cpp
index 1ddba4d93..e832bd27a 100644
--- a/konqueror/kttsplugin/khtmlkttsd.cpp
+++ b/konqueror/kttsplugin/khtmlkttsd.cpp
@@ -118,13 +118,13 @@ void KHTMLPluginKTTSD::slotReadOut()
}
// kdDebug() << "KHTMLPluginKTTSD::slotReadOut: query = " << query << endl;
- dataBuf.tqat(0); // reset data
+ dataBuf.at(0); // reset data
arg << query << "";
if ( !client->call("kttsd", "KSpeech", "setText(TQString,TQString)",
data, replyType, replyData, true) )
TQMessageBox::warning( 0, i18n( "DCOP Call Failed" ),
i18n( "The DCOP call setText failed." ));
- dataBuf.tqat(0);
+ dataBuf.at(0);
arg << 0;
if ( !client->call("kttsd", "KSpeech", "startText(uint)",
data, replyType, replyData, true) )
diff --git a/konqueror/listview/konq_infolistviewitem.cc b/konqueror/listview/konq_infolistviewitem.cc
index 842f870ec..b06baaf7d 100644
--- a/konqueror/listview/konq_infolistviewitem.cc
+++ b/konqueror/listview/konq_infolistviewitem.cc
@@ -206,7 +206,7 @@ void KonqInfoListViewItem::setDisabled( bool disabled )
setPixmap( 0, m_fileitem->pixmap( iconSize, state() ) );
}
-void KonqInfoListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _tqalignment )
+void KonqInfoListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _alignment )
{
TQColorGroup cg( _cg );
@@ -242,7 +242,7 @@ void KonqInfoListViewItem::paintCell( TQPainter *_painter, const TQColorGroup &
_width = newWidth;
}
- KListViewItem::paintCell( _painter, cg, _column, _width, _tqalignment );
+ KListViewItem::paintCell( _painter, cg, _column, _width, _alignment );
}
void KonqInfoListViewItem::paintFocus( TQPainter * _painter, const TQColorGroup & cg, const TQRect & _r )
diff --git a/konqueror/listview/konq_infolistviewitem.h b/konqueror/listview/konq_infolistviewitem.h
index 2ba7b8067..e81928118 100644
--- a/konqueror/listview/konq_infolistviewitem.h
+++ b/konqueror/listview/konq_infolistviewitem.h
@@ -56,7 +56,7 @@ class KonqInfoListViewItem : public KonqBaseListViewItem
virtual ~KonqInfoListViewItem() { }
virtual void paintCell( TQPainter *_painter, const TQColorGroup & cg,
- int column, int width, int tqalignment );
+ int column, int width, int alignment );
virtual void paintFocus( TQPainter * _painter, const TQColorGroup & cg, const TQRect & r );
virtual void updateContents();
virtual void setDisabled( bool disabled );
diff --git a/konqueror/listview/konq_listview.cc b/konqueror/listview/konq_listview.cc
index 61e30d269..14a909803 100644
--- a/konqueror/listview/konq_listview.cc
+++ b/konqueror/listview/konq_listview.cc
@@ -169,7 +169,7 @@ void ListViewBrowserExtension::rename()
const TQString txt = le->text();
TQString pattern;
KMimeType::diagnoseFileName( txt, pattern );
- if (!pattern.isEmpty() && pattern.tqat(0)=='*' && pattern.find('*',1)==-1)
+ if (!pattern.isEmpty() && pattern.at(0)=='*' && pattern.find('*',1)==-1)
le->setSelection(0, txt.length()-pattern.stripWhiteSpace().length()+1);
else
{
diff --git a/konqueror/listview/konq_listviewitems.cc b/konqueror/listview/konq_listviewitems.cc
index 57da1803b..016f3d77a 100644
--- a/konqueror/listview/konq_listviewitems.cc
+++ b/konqueror/listview/konq_listviewitems.cc
@@ -173,7 +173,7 @@ void KonqListViewItem::setActive( bool active )
if ( m_bActive == active )
return;
- //#### Optimize away tqrepaint if possible, like the iconview does?
+ //#### Optimize away repaint if possible, like the iconview does?
KonqBaseListViewItem::setActive( active );
int iconSize = m_pListViewWidget->iconSize();
iconSize = iconSize ? iconSize : KGlobal::iconLoader()->currentSize( KIcon::Small ); // Default = small
@@ -203,7 +203,7 @@ void KonqListViewItem::setPixmap( int column, const TQPixmap& pm )
int newWidth = pm.isNull() ? 0 : pm.width();
int newHeight = pm.isNull() ? 0 : pm.height();
- // If the height or width have changed then we're going to have to tqrepaint
+ // If the height or width have changed then we're going to have to repaint
// this whole thing. Fortunately since most of the calls are coming from
// setActive() this is the uncommon case.
@@ -234,7 +234,7 @@ const TQPixmap* KonqListViewItem::pixmap( int column ) const
if ((int)m_pixmaps.count() <= column)
return 0;
- TQPixmap *pm = m_pixmaps.tqat( column, &ok );
+ TQPixmap *pm = m_pixmaps.at( column, &ok );
if( !ok )
return 0;
return pm;
@@ -294,7 +294,7 @@ int KonqBaseListViewItem::compare( TQListViewItem* item, int col, bool ascending
}
}
-void KonqListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _tqalignment )
+void KonqListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _alignment )
{
TQColorGroup cg( _cg );
@@ -330,7 +330,7 @@ void KonqListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg,
_width = newWidth;
}
- KListViewItem::paintCell( _painter, cg, _column, _width, _tqalignment );
+ KListViewItem::paintCell( _painter, cg, _column, _width, _alignment );
}
void KonqListViewItem::paintFocus( TQPainter * _painter, const TQColorGroup & cg, const TQRect & _r )
diff --git a/konqueror/listview/konq_listviewitems.h b/konqueror/listview/konq_listviewitems.h
index 8e78b10f0..b54f1c2db 100644
--- a/konqueror/listview/konq_listviewitems.h
+++ b/konqueror/listview/konq_listviewitems.h
@@ -107,7 +107,7 @@ class KonqListViewItem : public KonqBaseListViewItem
virtual ~KonqListViewItem();
virtual void paintCell( TQPainter *_painter, const TQColorGroup & cg,
- int column, int width, int tqalignment );
+ int column, int width, int alignment );
virtual void paintFocus( TQPainter * _painter, const TQColorGroup & cg, const TQRect & r );
virtual void updateContents();
virtual void setDisabled( bool disabled );
diff --git a/konqueror/listview/konq_listviewwidget.cc b/konqueror/listview/konq_listviewwidget.cc
index daad55033..b7362603f 100644
--- a/konqueror/listview/konq_listviewwidget.cc
+++ b/konqueror/listview/konq_listviewwidget.cc
@@ -259,7 +259,7 @@ void KonqBaseListViewWidget::readProtocolConfig( const KURL & url )
//search the column in confColumns
for ( unsigned int j = 0; j < NumberOfAtoms; j++ )
{
- if ( confColumns[j].name == *lstColumns.tqat(i) )
+ if ( confColumns[j].name == *lstColumns.at(i) )
{
confColumns[j].displayThisOne = true;
confColumns[j].displayInColumn = currentColumn;
@@ -268,7 +268,7 @@ void KonqBaseListViewWidget::readProtocolConfig( const KURL & url )
currentColumn++;
if ( i < lstColumnWidths.count() )
- confColumns[j].width = *lstColumnWidths.tqat(i);
+ confColumns[j].width = *lstColumnWidths.at(i);
else
{
// Default Column widths
diff --git a/konqueror/listview/konq_listviewwidget.h b/konqueror/listview/konq_listviewwidget.h
index c55996306..6224be965 100644
--- a/konqueror/listview/konq_listviewwidget.h
+++ b/konqueror/listview/konq_listviewwidget.h
@@ -177,7 +177,7 @@ protected slots:
virtual void slotRedirection( const KURL & );
void slotPopupMenu( TQListViewItem *, const TQPoint&, int );
- // forces a tqrepaint on column size changes / branch expansion
+ // forces a repaint on column size changes / branch expansion
// when there is a background pixmap
void slotUpdateBackground();
diff --git a/konqueror/listview/konq_textviewitem.cc b/konqueror/listview/konq_textviewitem.cc
index 0d40ecfce..8e03e171e 100644
--- a/konqueror/listview/konq_textviewitem.cc
+++ b/konqueror/listview/konq_textviewitem.cc
@@ -200,7 +200,7 @@ void KonqTextViewItem::updateContents()
};
}
-void KonqTextViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _tqalignment )
+void KonqTextViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _alignment )
{
TQColorGroup cg( _cg );
cg.setColor(TQColorGroup::Text, static_cast<KonqTextViewWidget *>(listView())->colors[type]);
@@ -208,7 +208,7 @@ void KonqTextViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg,
// cg.setColor(TQColorGroup::HighlightedText, static_cast<KonqTextViewWidget *>(listView())->highlight[type]);
// cg.setColor(TQColorGroup::Highlight, Qt::darkGray);
- KListViewItem::paintCell( _painter, cg, _column, _width, _tqalignment );
+ KListViewItem::paintCell( _painter, cg, _column, _width, _alignment );
}
/*void KonqTextViewItem::paintFocus( TQPainter *_p, const TQColorGroup &_cg, const TQRect &_r )
diff --git a/konqueror/listview/konq_textviewitem.h b/konqueror/listview/konq_textviewitem.h
index 02a534688..f091781e2 100644
--- a/konqueror/listview/konq_textviewitem.h
+++ b/konqueror/listview/konq_textviewitem.h
@@ -57,7 +57,7 @@ class KonqTextViewItem : public KonqBaseListViewItem
// virtual TQString key( int _column, bool asc) const;
/** Call this before destroying the text view (decreases reference count
* on the view)*/
- virtual void paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _tqalignment );
+ virtual void paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _alignment );
// virtual void paintFocus( TQPainter *_painter, const TQColorGroup & _cg, const TQRect & r );
virtual void updateContents();
diff --git a/konqueror/sidebar/sidebar_widget.cpp b/konqueror/sidebar/sidebar_widget.cpp
index 6f178543a..8a5395b65 100644
--- a/konqueror/sidebar/sidebar_widget.cpp
+++ b/konqueror/sidebar/sidebar_widget.cpp
@@ -169,7 +169,7 @@ static TQString findFileName(const TQString* tmpl,bool universal, const TQString
void addBackEnd::activatedAddMenu(int id)
{
- kdDebug() << "activatedAddMenu: " << TQString("%1").tqarg(id) << endl;
+ kdDebug() << "activatedAddMenu: " << TQString("%1").arg(id) << endl;
if (((uint)id) == libNames.size())
doRollBack();
if(((uint)id) >= libNames.size())
@@ -178,13 +178,13 @@ void addBackEnd::activatedAddMenu(int id)
KLibLoader *loader = KLibLoader::self();
// try to load the library
- TQString libname = *libNames.tqat(id);
+ TQString libname = *libNames.at(id);
KLibrary *lib = loader->library(TQFile::encodeName(libname));
if (lib)
{
// get the create_ function
TQString factory("add_");
- factory = factory+(*libNames.tqat(id));
+ factory = factory+(*libNames.at(id));
void *add = lib->symbol(TQFile::encodeName(factory));
if (add)
@@ -194,7 +194,7 @@ void addBackEnd::activatedAddMenu(int id)
TQMap<TQString,TQString> map;
func = (bool (*)(TQString*, TQString*, TQMap<TQString,TQString> *)) add;
TQString *tmp = new TQString("");
- if (func(tmp,libParam.tqat(id),&map))
+ if (func(tmp,libParam.at(id),&map))
{
TQString myFile = findFileName(tmp,m_universal,m_currentProfile);
@@ -219,7 +219,7 @@ void addBackEnd::activatedAddMenu(int id)
delete tmp;
}
} else {
- kdWarning() << "libname:" << libNames.tqat(id)
+ kdWarning() << "libname:" << libNames.at(id)
<< " doesn't specify a library!" << endl;
}
}
@@ -574,7 +574,7 @@ void Sidebar_Widget::activatedMenu(int id)
{
int tmpViewID=m_latestViewed;
for (uint i=0; i<m_buttons.count(); i++) {
- ButtonInfo *button = m_buttons.tqat(i);
+ ButtonInfo *button = m_buttons.at(i);
if ((int) i != tmpViewID)
{
if (button->dock && button->dock->isVisibleTo(this))
@@ -598,7 +598,7 @@ void Sidebar_Widget::activatedMenu(int id)
m_mainDockWidget->show();
if ((tmpLatestViewed>=0) && (tmpLatestViewed < (int) m_buttons.count()))
{
- ButtonInfo *button = m_buttons.tqat(tmpLatestViewed);
+ ButtonInfo *button = m_buttons.at(tmpLatestViewed);
if (button && button->dock)
{
m_noUpdate=true;
@@ -694,7 +694,7 @@ void Sidebar_Widget::updateButtons()
{
for (uint i = 0; i < m_buttons.count(); i++)
{
- ButtonInfo *button = m_buttons.tqat(i);
+ ButtonInfo *button = m_buttons.at(i);
if (button->dock)
{
m_noUpdate = true;
@@ -742,7 +742,7 @@ void Sidebar_Widget::createButtons()
for (uint i = 0; i < m_buttons.count(); i++)
{
- ButtonInfo *button = m_buttons.tqat(i);
+ ButtonInfo *button = m_buttons.at(i);
if (m_openViews.contains(button->file))
{
m_buttonBar->setTab(i,true);
@@ -763,7 +763,7 @@ bool Sidebar_Widget::openURL(const class KURL &url)
if (url.protocol()=="sidebar")
{
for (unsigned int i=0;i<m_buttons.count();i++)
- if (m_buttons.tqat(i)->file==url.path())
+ if (m_buttons.at(i)->file==url.path())
{
KMultiTabBarTab *tab = m_buttonBar->tab(i);
if (!tab->isOn())
@@ -778,7 +778,7 @@ bool Sidebar_Widget::openURL(const class KURL &url)
bool ret = false;
for (unsigned int i=0;i<m_buttons.count();i++)
{
- ButtonInfo *button = m_buttons.tqat(i);
+ ButtonInfo *button = m_buttons.at(i);
if (button->dock)
{
if ((button->dock->isVisibleTo(this)) && (button->module))
@@ -845,7 +845,7 @@ bool Sidebar_Widget::eventFilter(TQObject *obj, TQEvent *ev)
{
if (bt==m_buttonBar->tab(i))
{
- m_currentButton = m_buttons.tqat(i);
+ m_currentButton = m_buttons.at(i);
break;
}
}
@@ -953,7 +953,7 @@ bool Sidebar_Widget::createView( ButtonInfo *data)
void Sidebar_Widget::showHidePage(int page)
{
- ButtonInfo *info = m_buttons.tqat(page);
+ ButtonInfo *info = m_buttons.at(page);
if (!info->dock)
{
if (m_buttonBar->isTabRaised(page))
@@ -1072,7 +1072,7 @@ void Sidebar_Widget::dockWidgetHasUndocked(KDockWidget* wid)
kdDebug()<<" Sidebar_Widget::dockWidgetHasUndocked(KDockWidget*)"<<endl;
for (unsigned int i=0;i<m_buttons.count();i++)
{
- ButtonInfo *button = m_buttons.tqat(i);
+ ButtonInfo *button = m_buttons.at(i);
if (button->dock==wid)
{
if (m_buttonBar->isTabRaised(i))
@@ -1255,7 +1255,7 @@ Sidebar_Widget::~Sidebar_Widget()
m_noUpdate = true;
for (uint i=0;i<m_buttons.count();i++)
{
- ButtonInfo *button = m_buttons.tqat(i);
+ ButtonInfo *button = m_buttons.at(i);
if (button->dock)
button->dock->undock();
}
diff --git a/konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp b/konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp
index 0ceb93d13..f8d0cc0de 100644
--- a/konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp
+++ b/konqueror/sidebar/trees/dirtree_module/dirtree_item.cpp
@@ -108,7 +108,7 @@ bool KonqSidebarDirTreeItem::hasStandardIcon()
return m_fileItem->iconName() == "folder";
}
-void KonqSidebarDirTreeItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _tqalignment )
+void KonqSidebarDirTreeItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _alignment )
{
if (m_fileItem->isLink())
{
@@ -116,7 +116,7 @@ void KonqSidebarDirTreeItem::paintCell( TQPainter *_painter, const TQColorGroup
f.setItalic( TRUE );
_painter->setFont( f );
}
- TQListViewItem::paintCell( _painter, _cg, _column, _width, _tqalignment );
+ TQListViewItem::paintCell( _painter, _cg, _column, _width, _alignment );
}
KURL KonqSidebarDirTreeItem::externalURL() const
diff --git a/konqueror/sidebar/trees/dirtree_module/dirtree_item.h b/konqueror/sidebar/trees/dirtree_module/dirtree_item.h
index 3a599c7e9..050f19424 100644
--- a/konqueror/sidebar/trees/dirtree_module/dirtree_item.h
+++ b/konqueror/sidebar/trees/dirtree_module/dirtree_item.h
@@ -36,7 +36,7 @@ public:
virtual void setOpen( bool open );
- virtual void paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _tqalignment );
+ virtual void paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _alignment );
virtual bool acceptsDrops( const TQStrList & formats );
virtual void drop( TQDropEvent * ev );
diff --git a/konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp b/konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp
index b83926e21..ac26b1285 100644
--- a/konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp
+++ b/konqueror/sidebar/trees/dirtree_module/dirtree_module.cpp
@@ -357,7 +357,7 @@ void KonqSidebarDirTreeModule::listDirectory( KonqSidebarTreeItem *item )
if (openItem)
{
// We have this directory listed already, just copy the entries as we
- // can't use the dirlister, it would tqinvalidate the old entries
+ // can't use the dirlister, it would invalidate the old entries
int size = KGlobal::iconLoader()->currentSize( KIcon::Small );
KonqSidebarTreeItem * parentItem = item;
KonqSidebarDirTreeItem *oldItem = static_cast<KonqSidebarDirTreeItem *> (openItem->firstChild());
@@ -574,7 +574,7 @@ void KonqSidebarDirTreeModule::slotListingStopped( const KURL & url )
if ( item->childCount() == 0 )
{
item->setExpandable( false );
- item->tqrepaint();
+ item->repaint();
}
m_pTree->stopAnimation( item );
diff --git a/konqueror/sidebar/trees/history_module/history_item.cpp b/konqueror/sidebar/trees/history_module/history_item.cpp
index ad2d2a7e2..0d31551f9 100644
--- a/konqueror/sidebar/trees/history_module/history_item.cpp
+++ b/konqueror/sidebar/trees/history_module/history_item.cpp
@@ -126,7 +126,7 @@ TQString KonqSidebarHistoryItem::toolTipText() const
}
void KonqSidebarHistoryItem::paintCell( TQPainter *p, const TQColorGroup & cg,
- int column, int width, int tqalignment )
+ int column, int width, int alignment )
{
TQDateTime dt;
TQDateTime current = TQDateTime::currentDateTime();
@@ -149,7 +149,7 @@ void KonqSidebarHistoryItem::paintCell( TQPainter *p, const TQColorGroup & cg,
p->setFont( s_settings->m_fontOlderThan );
}
- KonqSidebarTreeItem::paintCell( p, cg, column, width, tqalignment );
+ KonqSidebarTreeItem::paintCell( p, cg, column, width, alignment );
}
///////////////////////////////////////////////////////////////////
diff --git a/konqueror/sidebar/trees/history_module/history_item.h b/konqueror/sidebar/trees/history_module/history_item.h
index 0ddc7ae4e..1c6c7c4c4 100644
--- a/konqueror/sidebar/trees/history_module/history_item.h
+++ b/konqueror/sidebar/trees/history_module/history_item.h
@@ -60,7 +60,7 @@ public:
static void setSettings( KonqSidebarHistorySettings *s ) { s_settings = s; }
virtual void paintCell( TQPainter *, const TQColorGroup & cg, int column,
- int width, int tqalignment );
+ int width, int alignment );
private:
const KonqHistoryEntry *m_entry;
diff --git a/konqueror/sidebar/trees/konq_sidebartree.cpp b/konqueror/sidebar/trees/konq_sidebartree.cpp
index 7755286bc..dc954322f 100644
--- a/konqueror/sidebar/trees/konq_sidebartree.cpp
+++ b/konqueror/sidebar/trees/konq_sidebartree.cpp
@@ -516,7 +516,7 @@ void KonqSidebarTree::slotAutoOpenFolder()
return;
m_dropItem->setOpen( true );
- m_dropItem->tqrepaint();
+ m_dropItem->repaint();
}
void KonqSidebarTree::rescanConfiguration()
diff --git a/konqueror/sidebar/trees/konqsidebar_tree.cpp b/konqueror/sidebar/trees/konqsidebar_tree.cpp
index 3e18366ab..ed41a8e76 100644
--- a/konqueror/sidebar/trees/konqsidebar_tree.cpp
+++ b/konqueror/sidebar/trees/konqsidebar_tree.cpp
@@ -150,7 +150,7 @@ extern "C"
{
int id=names.findIndex( item );
if (id==-1) return false;
- KSimpleConfig ksc2(*list.tqat(id));
+ KSimpleConfig ksc2(*list.at(id));
ksc2.setGroup("Desktop Entry");
map->insert("Type","Link");
map->insert("Icon",ksc2.readEntry("Icon"));
diff --git a/konqueror/iconview/konq_iconview.cc b/konqueror/iconview/konq_iconview.cc
index 71d1fb7a6..3380da6d6 100644
--- a/konqueror/iconview/konq_iconview.cc
+++ b/konqueror/iconview/konq_iconview.cc
@@ -206,7 +206,7 @@ KonqKfmIconView::KonqKfmIconView( TQWidget *parentWidget, TQObject *parent, cons
setXMLFile( "konq_iconview.rc" );
// Don't tqrepaint on configuration changes during construction
m_bInit = true;
m_paDotFiles = new KToggleAction( i18n( "Show &Hidden Files" ), 0, this, TQT_SLOT( slotShowDot() ),
@@ -686,7 +686,7 @@ void KonqKfmIconView::newIconSize( int size )
// Stop a preview job that might be running
m_pIconView->stopImagePreview();
// Set icons size, arrage items in grid and tqrepaint the whole view
m_pIconView->setIcons( size );
// If previews are enabled start a new job
@@ -873,7 +873,7 @@ void KonqKfmIconView::slotCanceled( const KURL& url )
if ( !m_pIconView->viewport()->isUpdatesEnabled() )
{
m_pIconView->viewport()->setUpdatesEnabled( true );
- m_pIconView->viewport()->tqrepaint();
+ m_pIconView->viewport()->repaint();
}
if ( m_pEnsureVisible ){
m_pIconView->ensureItemVisible( m_pEnsureVisible );
@@ -889,11 +889,11 @@ void KonqKfmIconView::slotCompleted()
m_pTimeoutRefreshTimer->stop();
// If updates to the viewport are still blocked (so slotNewItems() has
// not been called), a viewport tqrepaint is forced.
if ( !m_pIconView->viewport()->isUpdatesEnabled() )
{
m_pIconView->viewport()->setUpdatesEnabled( true );
- m_pIconView->viewport()->tqrepaint();
+ m_pIconView->viewport()->repaint();
}
// Root item ? Store root item in konqiconviewwidget (whether 0L or not)
@@ -1136,7 +1136,7 @@ void KonqKfmIconView::slotRefreshItems( const KFileItemList& entries )
}
else
{
// In case we replace a big icon with a small one, need to tqrepaint.
if ( bNeedRepaint )
m_pIconView->updateContents();
}
@@ -1248,7 +1248,7 @@ void KonqKfmIconView::slotRefreshViewport()
TQWidget * vp = m_pIconView->viewport();
bool prevState = vp->isUpdatesEnabled();
vp->setUpdatesEnabled( true );
- vp->tqrepaint();
+ vp->repaint();
vp->setUpdatesEnabled( prevState );
}
@@ -206,7 +206,7 @@ KonqKfmIconView::KonqKfmIconView( TQWidget *parentWidget, TQObject *parent, cons
setXMLFile( "konq_iconview.rc" );
- // Don't tqrepaint on configuration changes during construction
+ // Don't repaint on configuration changes during construction
m_bInit = true;
m_paDotFiles = new KToggleAction( i18n( "Show &Hidden Files" ), 0, this, TQT_SLOT( slotShowDot() ),
@@ -686,7 +686,7 @@ void KonqKfmIconView::newIconSize( int size )
// Stop a preview job that might be running
m_pIconView->stopImagePreview();
- // Set icons size, arrage items in grid and tqrepaint the whole view
+ // Set icons size, arrage items in grid and repaint the whole view
m_pIconView->setIcons( size );
// If previews are enabled start a new job
@@ -889,11 +889,11 @@ void KonqKfmIconView::slotCompleted()
m_pTimeoutRefreshTimer->stop();
// If updates to the viewport are still blocked (so slotNewItems() has
- // not been called), a viewport tqrepaint is forced.
+ // not been called), a viewport repaint is forced.
if ( !m_pIconView->viewport()->isUpdatesEnabled() )
{
@@ -1136,7 +1136,7 @@ void KonqKfmIconView::slotRefreshItems( const KFileItemList& entries )
else
{
- // In case we replace a big icon with a small one, need to tqrepaint.
+ // In case we replace a big icon with a small one, need to repaint.
if ( bNeedRepaint )
m_pIconView->updateContents();
diff --git a/konqueror/konq_combo.cc b/konqueror/konq_combo.cc
index 8c5218920..fc2f6b901 100644
--- a/konqueror/konq_combo.cc
+++ b/konqueror/konq_combo.cc
@@ -307,7 +307,7 @@ void KonqCombo::updatePixmaps()
updateItem( prov->pixmapFor( text( i ) ), text( i ), i, titleOfURL( text( i ) ) );
}
setUpdatesEnabled( true );
- tqrepaint();
+ repaint();
restoreState();
}
@@ -646,7 +646,7 @@ void KonqCombo::paintEvent( TQPaintEvent *pe )
void KonqCombo::setPageSecurity( int pageSecurity )
{
m_pageSecurity = pageSecurity;
- tqrepaint();
+ repaint();
}
bool KonqCombo::hasSufficientContrast(const TQColor &c1, const TQColor &c2)
@@ -850,7 +850,7 @@ void KonqComboCompletionBox::setItems( const TQStringList& items )
insertStringList( items );
else {
//Keep track of whether we need to change anything,
//so we can avoid a tqrepaint for identical updates,
//to reduce flicker
bool dirty = false;
@@ -850,7 +850,7 @@ void KonqComboCompletionBox::setItems( const TQStringList& items )
else {
//Keep track of whether we need to change anything,
- //so we can avoid a tqrepaint for identical updates,
+ //so we can avoid a repaint for identical updates,
//to reduce flicker
bool dirty = false;